from . import orientationanalysis

def bad_data_neighbor_orientation_check(data_container_array, misorientation_tolerance = None, number_of_neighbors = None, good_voxels_array_path = None, cell_phases_array_path = None, crystal_structures_array_path = None, quats_array_path = None, observer = None) -> int:
  """Pythonic interface to BadDataNeighborOrientationCheck Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    misorientation_tolerance (float): Sets the "MisorientationTolerance" filter property
    number_of_neighbors (int): Sets the "NumberOfNeighbors" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.BadDataNeighborOrientationCheck()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if misorientation_tolerance is not None:
    filter.MisorientationTolerance = misorientation_tolerance
  if number_of_neighbors is not None:
    filter.NumberOfNeighbors = number_of_neighbors
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  filter.execute()
  return filter.ErrorCode

def change_angle_representation(data_container_array, conversion_type = None, cell_euler_angles_array_path = None, observer = None) -> int:
  """Pythonic interface to ChangeAngleRepresentation Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    conversion_type (int): Sets the "ConversionType" filter property
    cell_euler_angles_array_path (DataArrayPath): Sets the "CellEulerAnglesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.ChangeAngleRepresentation()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if conversion_type is not None:
    filter.ConversionType = conversion_type
  if cell_euler_angles_array_path is not None:
    filter.CellEulerAnglesArrayPath = cell_euler_angles_array_path
  filter.execute()
  return filter.ErrorCode

def convert_hex_grid_to_square_grid(data_container_array, input_path = None, output_path = None, output_prefix = None, file_prefix = None, file_suffix = None, file_extension = None, padding_digits = None, hex_grid_stack = None, observer = None) -> int:
  """Pythonic interface to ConvertHexGridToSquareGrid Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_path (QString): Sets the "InputPath" filter property
    output_path (QString): Sets the "OutputPath" filter property
    output_prefix (QString): Sets the "OutputPrefix" filter property
    file_prefix (QString): Sets the "FilePrefix" filter property
    file_suffix (QString): Sets the "FileSuffix" filter property
    file_extension (QString): Sets the "FileExtension" filter property
    padding_digits (int): Sets the "PaddingDigits" filter property
    hex_grid_stack (int): Sets the "HexGridStack" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.ConvertHexGridToSquareGrid()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_path is not None:
    filter.InputPath = input_path
  if output_path is not None:
    filter.OutputPath = output_path
  if output_prefix is not None:
    filter.OutputPrefix = output_prefix
  if file_prefix is not None:
    filter.FilePrefix = file_prefix
  if file_suffix is not None:
    filter.FileSuffix = file_suffix
  if file_extension is not None:
    filter.FileExtension = file_extension
  if padding_digits is not None:
    filter.PaddingDigits = padding_digits
  if hex_grid_stack is not None:
    filter.HexGridStack = hex_grid_stack
  filter.execute()
  return filter.ErrorCode

def convert_orientations(data_container_array, input_type = None, output_type = None, input_orientation_array_path = None, output_orientation_array_name = None, observer = None) -> int:
  """Pythonic interface to ConvertOrientations Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_type (int): Sets the "InputType" filter property
    output_type (int): Sets the "OutputType" filter property
    input_orientation_array_path (DataArrayPath): Sets the "InputOrientationArrayPath" filter property
    output_orientation_array_name (QString): Sets the "OutputOrientationArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.ConvertOrientations()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_type is not None:
    filter.InputType = input_type
  if output_type is not None:
    filter.OutputType = output_type
  if input_orientation_array_path is not None:
    filter.InputOrientationArrayPath = input_orientation_array_path
  if output_orientation_array_name is not None:
    filter.OutputOrientationArrayName = output_orientation_array_name
  filter.execute()
  return filter.ErrorCode

def convert_quaternion(data_container_array, quaternion_data_array_path = None, output_data_array_path = None, delete_original_data = None, conversion_type = None, observer = None) -> int:
  """Pythonic interface to ConvertQuaternion Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    quaternion_data_array_path (DataArrayPath): Sets the "QuaternionDataArrayPath" filter property
    output_data_array_path (DataArrayPath): Sets the "OutputDataArrayPath" filter property
    delete_original_data (bool): Sets the "DeleteOriginalData" filter property
    conversion_type (int32_t): Sets the "ConversionType" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.ConvertQuaternion()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if quaternion_data_array_path is not None:
    filter.QuaternionDataArrayPath = quaternion_data_array_path
  if output_data_array_path is not None:
    filter.OutputDataArrayPath = output_data_array_path
  if delete_original_data is not None:
    filter.DeleteOriginalData = delete_original_data
  if conversion_type is not None:
    filter.ConversionType = conversion_type
  filter.execute()
  return filter.ErrorCode

def create_ensemble_info(data_container_array, data_container_name = None, cell_ensemble_attribute_matrix_name = None, ensemble = None, crystal_structures_array_name = None, phase_types_array_name = None, phase_names_array_name = None, observer = None) -> int:
  """Pythonic interface to CreateEnsembleInfo Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_ensemble_attribute_matrix_name (QString): Sets the "CellEnsembleAttributeMatrixName" filter property
    ensemble (EnsembleInfo): Sets the "Ensemble" filter property
    crystal_structures_array_name (QString): Sets the "CrystalStructuresArrayName" filter property
    phase_types_array_name (QString): Sets the "PhaseTypesArrayName" filter property
    phase_names_array_name (QString): Sets the "PhaseNamesArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.CreateEnsembleInfo()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_ensemble_attribute_matrix_name is not None:
    filter.CellEnsembleAttributeMatrixName = cell_ensemble_attribute_matrix_name
  if ensemble is not None:
    filter.Ensemble = ensemble
  if crystal_structures_array_name is not None:
    filter.CrystalStructuresArrayName = crystal_structures_array_name
  if phase_types_array_name is not None:
    filter.PhaseTypesArrayName = phase_types_array_name
  if phase_names_array_name is not None:
    filter.PhaseNamesArrayName = phase_names_array_name
  filter.execute()
  return filter.ErrorCode

def create_lambert_sphere(data_container_array, hemisphere = None, image_data_array_path = None, quad_data_container_name = None, triangle_data_container_name = None, edge_data_container_name = None, vertex_data_container_name = None, vertex_attribute_matrix_name = None, edge_attribute_matrix_name = None, face_attribute_matrix_name = None, create_vertex_geometry = None, create_edge_geometry = None, create_triangle_geometry = None, create_quad_geometry = None, observer = None) -> int:
  """Pythonic interface to CreateLambertSphere Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    hemisphere (int): Sets the "Hemisphere" filter property
    image_data_array_path (DataArrayPath): Sets the "ImageDataArrayPath" filter property
    quad_data_container_name (DataArrayPath): Sets the "QuadDataContainerName" filter property
    triangle_data_container_name (DataArrayPath): Sets the "TriangleDataContainerName" filter property
    edge_data_container_name (DataArrayPath): Sets the "EdgeDataContainerName" filter property
    vertex_data_container_name (DataArrayPath): Sets the "VertexDataContainerName" filter property
    vertex_attribute_matrix_name (QString): Sets the "VertexAttributeMatrixName" filter property
    edge_attribute_matrix_name (QString): Sets the "EdgeAttributeMatrixName" filter property
    face_attribute_matrix_name (QString): Sets the "FaceAttributeMatrixName" filter property
    create_vertex_geometry (bool): Sets the "CreateVertexGeometry" filter property
    create_edge_geometry (bool): Sets the "CreateEdgeGeometry" filter property
    create_triangle_geometry (bool): Sets the "CreateTriangleGeometry" filter property
    create_quad_geometry (bool): Sets the "CreateQuadGeometry" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.CreateLambertSphere()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if hemisphere is not None:
    filter.Hemisphere = hemisphere
  if image_data_array_path is not None:
    filter.ImageDataArrayPath = image_data_array_path
  if quad_data_container_name is not None:
    filter.QuadDataContainerName = quad_data_container_name
  if triangle_data_container_name is not None:
    filter.TriangleDataContainerName = triangle_data_container_name
  if edge_data_container_name is not None:
    filter.EdgeDataContainerName = edge_data_container_name
  if vertex_data_container_name is not None:
    filter.VertexDataContainerName = vertex_data_container_name
  if vertex_attribute_matrix_name is not None:
    filter.VertexAttributeMatrixName = vertex_attribute_matrix_name
  if edge_attribute_matrix_name is not None:
    filter.EdgeAttributeMatrixName = edge_attribute_matrix_name
  if face_attribute_matrix_name is not None:
    filter.FaceAttributeMatrixName = face_attribute_matrix_name
  if create_vertex_geometry is not None:
    filter.CreateVertexGeometry = create_vertex_geometry
  if create_edge_geometry is not None:
    filter.CreateEdgeGeometry = create_edge_geometry
  if create_triangle_geometry is not None:
    filter.CreateTriangleGeometry = create_triangle_geometry
  if create_quad_geometry is not None:
    filter.CreateQuadGeometry = create_quad_geometry
  filter.execute()
  return filter.ErrorCode

def ebsd_to_h5_ebsd(data_container_array, input_path = None, output_file = None, file_prefix = None, file_suffix = None, file_extension = None, padding_digits = None, z_start_index = None, z_end_index = None, z_resolution = None, sample_transformation = None, euler_transformation = None, observer = None) -> int:
  """Pythonic interface to EbsdToH5Ebsd Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_path (QString): Sets the "InputPath" filter property
    output_file (QString): Sets the "OutputFile" filter property
    file_prefix (QString): Sets the "FilePrefix" filter property
    file_suffix (QString): Sets the "FileSuffix" filter property
    file_extension (QString): Sets the "FileExtension" filter property
    padding_digits (int): Sets the "PaddingDigits" filter property
    z_start_index (int64_t): Sets the "ZStartIndex" filter property
    z_end_index (int64_t): Sets the "ZEndIndex" filter property
    z_resolution (float): Sets the "ZResolution" filter property
    sample_transformation (AxisAngleInput): Sets the "SampleTransformation" filter property
    euler_transformation (AxisAngleInput): Sets the "EulerTransformation" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.EbsdToH5Ebsd()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_path is not None:
    filter.InputPath = input_path
  if output_file is not None:
    filter.OutputFile = output_file
  if file_prefix is not None:
    filter.FilePrefix = file_prefix
  if file_suffix is not None:
    filter.FileSuffix = file_suffix
  if file_extension is not None:
    filter.FileExtension = file_extension
  if padding_digits is not None:
    filter.PaddingDigits = padding_digits
  if z_start_index is not None:
    filter.ZStartIndex = z_start_index
  if z_end_index is not None:
    filter.ZEndIndex = z_end_index
  if z_resolution is not None:
    filter.ZResolution = z_resolution
  if sample_transformation is not None:
    filter.SampleTransformation = sample_transformation
  if euler_transformation is not None:
    filter.EulerTransformation = euler_transformation
  filter.execute()
  return filter.ErrorCode

def e_msoft_so3_sampler(data_container_array, sample_mode_selector = None, point_group = None, numsp = None, mis_or = None, ref_or = None, mis_or_full = None, ref_or_full = None, offset_grid = None, euler_angles_array_name = None, data_container_name = None, e_msoft_attribute_matrix_name = None, observer = None) -> int:
  """Pythonic interface to EMsoftSO3Sampler Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    sample_mode_selector (int): Sets the "sampleModeSelector" filter property
    point_group (int): Sets the "PointGroup" filter property
    numsp (int): Sets the "Numsp" filter property
    mis_or (double): Sets the "MisOr" filter property
    ref_or (FloatVec3Type): Sets the "RefOr" filter property
    mis_or_full (double): Sets the "MisOrFull" filter property
    ref_or_full (FloatVec3Type): Sets the "RefOrFull" filter property
    offset_grid (bool): Sets the "OffsetGrid" filter property
    euler_angles_array_name (QString): Sets the "EulerAnglesArrayName" filter property
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    e_msoft_attribute_matrix_name (QString): Sets the "EMsoftAttributeMatrixName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.EMsoftSO3Sampler()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if sample_mode_selector is not None:
    filter.sampleModeSelector = sample_mode_selector
  if point_group is not None:
    filter.PointGroup = point_group
  if numsp is not None:
    filter.Numsp = numsp
  if mis_or is not None:
    filter.MisOr = mis_or
  if ref_or is not None:
    filter.RefOr = ref_or
  if mis_or_full is not None:
    filter.MisOrFull = mis_or_full
  if ref_or_full is not None:
    filter.RefOrFull = ref_or_full
  if offset_grid is not None:
    filter.OffsetGrid = offset_grid
  if euler_angles_array_name is not None:
    filter.EulerAnglesArrayName = euler_angles_array_name
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if e_msoft_attribute_matrix_name is not None:
    filter.EMsoftAttributeMatrixName = e_msoft_attribute_matrix_name
  filter.execute()
  return filter.ErrorCode

def ensemble_info_reader(data_container_array, data_container_name = None, cell_ensemble_attribute_matrix_name = None, input_file = None, crystal_structures_array_name = None, phase_types_array_name = None, observer = None) -> int:
  """Pythonic interface to EnsembleInfoReader Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_ensemble_attribute_matrix_name (QString): Sets the "CellEnsembleAttributeMatrixName" filter property
    input_file (QString): Sets the "InputFile" filter property
    crystal_structures_array_name (QString): Sets the "CrystalStructuresArrayName" filter property
    phase_types_array_name (QString): Sets the "PhaseTypesArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.EnsembleInfoReader()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_ensemble_attribute_matrix_name is not None:
    filter.CellEnsembleAttributeMatrixName = cell_ensemble_attribute_matrix_name
  if input_file is not None:
    filter.InputFile = input_file
  if crystal_structures_array_name is not None:
    filter.CrystalStructuresArrayName = crystal_structures_array_name
  if phase_types_array_name is not None:
    filter.PhaseTypesArrayName = phase_types_array_name
  filter.execute()
  return filter.ErrorCode

def find_avg_c_axes(data_container_array, quats_array_path = None, feature_ids_array_path = None, avg_c_axes_array_path = None, observer = None) -> int:
  """Pythonic interface to FindAvgCAxes Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    avg_c_axes_array_path (DataArrayPath): Sets the "AvgCAxesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindAvgCAxes()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if avg_c_axes_array_path is not None:
    filter.AvgCAxesArrayPath = avg_c_axes_array_path
  filter.execute()
  return filter.ErrorCode

def find_avg_orientations(data_container_array, feature_ids_array_path = None, cell_phases_array_path = None, quats_array_path = None, crystal_structures_array_path = None, avg_quats_array_path = None, avg_euler_angles_array_path = None, observer = None) -> int:
  """Pythonic interface to FindAvgOrientations Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    avg_euler_angles_array_path (DataArrayPath): Sets the "AvgEulerAnglesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindAvgOrientations()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if avg_euler_angles_array_path is not None:
    filter.AvgEulerAnglesArrayPath = avg_euler_angles_array_path
  filter.execute()
  return filter.ErrorCode

def find_boundary_strengths(data_container_array, loading = None, surface_mesh_face_labels_array_path = None, avg_quats_array_path = None, feature_phases_array_path = None, crystal_structures_array_path = None, surface_mesh_f1s_array_name = None, surface_mesh_f1spts_array_name = None, surface_mesh_f7s_array_name = None, surface_meshm_primes_array_name = None, observer = None) -> int:
  """Pythonic interface to FindBoundaryStrengths Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    loading (FloatVec3Type): Sets the "Loading" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    surface_mesh_f1s_array_name (QString): Sets the "SurfaceMeshF1sArrayName" filter property
    surface_mesh_f1spts_array_name (QString): Sets the "SurfaceMeshF1sptsArrayName" filter property
    surface_mesh_f7s_array_name (QString): Sets the "SurfaceMeshF7sArrayName" filter property
    surface_meshm_primes_array_name (QString): Sets the "SurfaceMeshmPrimesArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindBoundaryStrengths()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if loading is not None:
    filter.Loading = loading
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if surface_mesh_f1s_array_name is not None:
    filter.SurfaceMeshF1sArrayName = surface_mesh_f1s_array_name
  if surface_mesh_f1spts_array_name is not None:
    filter.SurfaceMeshF1sptsArrayName = surface_mesh_f1spts_array_name
  if surface_mesh_f7s_array_name is not None:
    filter.SurfaceMeshF7sArrayName = surface_mesh_f7s_array_name
  if surface_meshm_primes_array_name is not None:
    filter.SurfaceMeshmPrimesArrayName = surface_meshm_primes_array_name
  filter.execute()
  return filter.ErrorCode

def find_c_axis_locations(data_container_array, quats_array_path = None, c_axis_locations_array_name = None, observer = None) -> int:
  """Pythonic interface to FindCAxisLocations Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    c_axis_locations_array_name (QString): Sets the "CAxisLocationsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindCAxisLocations()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if c_axis_locations_array_name is not None:
    filter.CAxisLocationsArrayName = c_axis_locations_array_name
  filter.execute()
  return filter.ErrorCode

def find_dists_to_charact_g_bs(data_container_array, crystal_structures_array_path = None, feature_euler_angles_array_path = None, feature_phases_array_path = None, surface_mesh_face_labels_array_path = None, surface_mesh_face_normals_array_path = None, dist_to_tilt_array_path = None, dist_to_twist_array_path = None, dist_to_symmetric_array_path = None, dist_to180_tilt_array_path = None, observer = None) -> int:
  """Pythonic interface to FindDistsToCharactGBs Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    feature_euler_angles_array_path (DataArrayPath): Sets the "FeatureEulerAnglesArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    surface_mesh_face_normals_array_path (DataArrayPath): Sets the "SurfaceMeshFaceNormalsArrayPath" filter property
    dist_to_tilt_array_path (DataArrayPath): Sets the "DistToTiltArrayPath" filter property
    dist_to_twist_array_path (DataArrayPath): Sets the "DistToTwistArrayPath" filter property
    dist_to_symmetric_array_path (DataArrayPath): Sets the "DistToSymmetricArrayPath" filter property
    dist_to180_tilt_array_path (DataArrayPath): Sets the "DistTo180TiltArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindDistsToCharactGBs()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if feature_euler_angles_array_path is not None:
    filter.FeatureEulerAnglesArrayPath = feature_euler_angles_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if surface_mesh_face_normals_array_path is not None:
    filter.SurfaceMeshFaceNormalsArrayPath = surface_mesh_face_normals_array_path
  if dist_to_tilt_array_path is not None:
    filter.DistToTiltArrayPath = dist_to_tilt_array_path
  if dist_to_twist_array_path is not None:
    filter.DistToTwistArrayPath = dist_to_twist_array_path
  if dist_to_symmetric_array_path is not None:
    filter.DistToSymmetricArrayPath = dist_to_symmetric_array_path
  if dist_to180_tilt_array_path is not None:
    filter.DistTo180TiltArrayPath = dist_to180_tilt_array_path
  filter.execute()
  return filter.ErrorCode

def find_feature_neighbor_c_axis_misalignments(data_container_array, find_avg_misals = None, neighbor_list_array_path = None, c_axis_misalignment_list_array_name = None, avg_quats_array_path = None, feature_phases_array_path = None, crystal_structures_array_path = None, avg_c_axis_misalignments_array_name = None, observer = None) -> int:
  """Pythonic interface to FindFeatureNeighborCAxisMisalignments Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    find_avg_misals (bool): Sets the "FindAvgMisals" filter property
    neighbor_list_array_path (DataArrayPath): Sets the "NeighborListArrayPath" filter property
    c_axis_misalignment_list_array_name (QString): Sets the "CAxisMisalignmentListArrayName" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    avg_c_axis_misalignments_array_name (QString): Sets the "AvgCAxisMisalignmentsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindFeatureNeighborCAxisMisalignments()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if find_avg_misals is not None:
    filter.FindAvgMisals = find_avg_misals
  if neighbor_list_array_path is not None:
    filter.NeighborListArrayPath = neighbor_list_array_path
  if c_axis_misalignment_list_array_name is not None:
    filter.CAxisMisalignmentListArrayName = c_axis_misalignment_list_array_name
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if avg_c_axis_misalignments_array_name is not None:
    filter.AvgCAxisMisalignmentsArrayName = avg_c_axis_misalignments_array_name
  filter.execute()
  return filter.ErrorCode

def find_feature_reference_c_axis_misorientations(data_container_array, feature_ids_array_path = None, cell_phases_array_path = None, avg_c_axes_array_path = None, quats_array_path = None, feature_avg_c_axis_misorientations_array_name = None, feature_stdev_c_axis_misorientations_array_name = None, feature_reference_c_axis_misorientations_array_name = None, observer = None) -> int:
  """Pythonic interface to FindFeatureReferenceCAxisMisorientations Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    avg_c_axes_array_path (DataArrayPath): Sets the "AvgCAxesArrayPath" filter property
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    feature_avg_c_axis_misorientations_array_name (QString): Sets the "FeatureAvgCAxisMisorientationsArrayName" filter property
    feature_stdev_c_axis_misorientations_array_name (QString): Sets the "FeatureStdevCAxisMisorientationsArrayName" filter property
    feature_reference_c_axis_misorientations_array_name (QString): Sets the "FeatureReferenceCAxisMisorientationsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindFeatureReferenceCAxisMisorientations()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if avg_c_axes_array_path is not None:
    filter.AvgCAxesArrayPath = avg_c_axes_array_path
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if feature_avg_c_axis_misorientations_array_name is not None:
    filter.FeatureAvgCAxisMisorientationsArrayName = feature_avg_c_axis_misorientations_array_name
  if feature_stdev_c_axis_misorientations_array_name is not None:
    filter.FeatureStdevCAxisMisorientationsArrayName = feature_stdev_c_axis_misorientations_array_name
  if feature_reference_c_axis_misorientations_array_name is not None:
    filter.FeatureReferenceCAxisMisorientationsArrayName = feature_reference_c_axis_misorientations_array_name
  filter.execute()
  return filter.ErrorCode

def find_feature_reference_misorientations(data_container_array, feature_ids_array_path = None, cell_phases_array_path = None, crystal_structures_array_path = None, quats_array_path = None, avg_quats_array_path = None, gb_euclidean_distances_array_path = None, feature_avg_misorientations_array_name = None, feature_reference_misorientations_array_name = None, reference_orientation = None, observer = None) -> int:
  """Pythonic interface to FindFeatureReferenceMisorientations Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    gb_euclidean_distances_array_path (DataArrayPath): Sets the "GBEuclideanDistancesArrayPath" filter property
    feature_avg_misorientations_array_name (QString): Sets the "FeatureAvgMisorientationsArrayName" filter property
    feature_reference_misorientations_array_name (QString): Sets the "FeatureReferenceMisorientationsArrayName" filter property
    reference_orientation (int): Sets the "ReferenceOrientation" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindFeatureReferenceMisorientations()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if gb_euclidean_distances_array_path is not None:
    filter.GBEuclideanDistancesArrayPath = gb_euclidean_distances_array_path
  if feature_avg_misorientations_array_name is not None:
    filter.FeatureAvgMisorientationsArrayName = feature_avg_misorientations_array_name
  if feature_reference_misorientations_array_name is not None:
    filter.FeatureReferenceMisorientationsArrayName = feature_reference_misorientations_array_name
  if reference_orientation is not None:
    filter.ReferenceOrientation = reference_orientation
  filter.execute()
  return filter.ErrorCode

def find_gbcd(data_container_array, face_ensemble_attribute_matrix_name = None, gbcd_res = None, surface_mesh_face_labels_array_path = None, surface_mesh_face_normals_array_path = None, surface_mesh_face_areas_array_path = None, feature_euler_angles_array_path = None, feature_phases_array_path = None, crystal_structures_array_path = None, gbcd_array_name = None, observer = None) -> int:
  """Pythonic interface to FindGBCD Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    face_ensemble_attribute_matrix_name (QString): Sets the "FaceEnsembleAttributeMatrixName" filter property
    gbcd_res (float): Sets the "GBCDRes" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    surface_mesh_face_normals_array_path (DataArrayPath): Sets the "SurfaceMeshFaceNormalsArrayPath" filter property
    surface_mesh_face_areas_array_path (DataArrayPath): Sets the "SurfaceMeshFaceAreasArrayPath" filter property
    feature_euler_angles_array_path (DataArrayPath): Sets the "FeatureEulerAnglesArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    gbcd_array_name (QString): Sets the "GBCDArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindGBCD()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if face_ensemble_attribute_matrix_name is not None:
    filter.FaceEnsembleAttributeMatrixName = face_ensemble_attribute_matrix_name
  if gbcd_res is not None:
    filter.GBCDRes = gbcd_res
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if surface_mesh_face_normals_array_path is not None:
    filter.SurfaceMeshFaceNormalsArrayPath = surface_mesh_face_normals_array_path
  if surface_mesh_face_areas_array_path is not None:
    filter.SurfaceMeshFaceAreasArrayPath = surface_mesh_face_areas_array_path
  if feature_euler_angles_array_path is not None:
    filter.FeatureEulerAnglesArrayPath = feature_euler_angles_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if gbcd_array_name is not None:
    filter.GBCDArrayName = gbcd_array_name
  filter.execute()
  return filter.ErrorCode

def find_gbcd_metric_based(data_container_array, phase_of_interest = None, misorientation_rotation = None, chosen_limit_dists = None, num_sampl_pts = None, exclude_triple_lines = None, dist_output_file = None, err_output_file = None, save_relative_err = None, crystal_structures_array_path = None, feature_euler_angles_array_path = None, feature_phases_array_path = None, surface_mesh_face_labels_array_path = None, surface_mesh_face_normals_array_path = None, surface_mesh_face_areas_array_path = None, surface_mesh_feature_face_labels_array_path = None, node_types_array_path = None, observer = None) -> int:
  """Pythonic interface to FindGBCDMetricBased Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    phase_of_interest (int): Sets the "PhaseOfInterest" filter property
    misorientation_rotation (AxisAngleInput): Sets the "MisorientationRotation" filter property
    chosen_limit_dists (int): Sets the "ChosenLimitDists" filter property
    num_sampl_pts (int): Sets the "NumSamplPts" filter property
    exclude_triple_lines (bool): Sets the "ExcludeTripleLines" filter property
    dist_output_file (QString): Sets the "DistOutputFile" filter property
    err_output_file (QString): Sets the "ErrOutputFile" filter property
    save_relative_err (bool): Sets the "SaveRelativeErr" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    feature_euler_angles_array_path (DataArrayPath): Sets the "FeatureEulerAnglesArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    surface_mesh_face_normals_array_path (DataArrayPath): Sets the "SurfaceMeshFaceNormalsArrayPath" filter property
    surface_mesh_face_areas_array_path (DataArrayPath): Sets the "SurfaceMeshFaceAreasArrayPath" filter property
    surface_mesh_feature_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFeatureFaceLabelsArrayPath" filter property
    node_types_array_path (DataArrayPath): Sets the "NodeTypesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindGBCDMetricBased()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if phase_of_interest is not None:
    filter.PhaseOfInterest = phase_of_interest
  if misorientation_rotation is not None:
    filter.MisorientationRotation = misorientation_rotation
  if chosen_limit_dists is not None:
    filter.ChosenLimitDists = chosen_limit_dists
  if num_sampl_pts is not None:
    filter.NumSamplPts = num_sampl_pts
  if exclude_triple_lines is not None:
    filter.ExcludeTripleLines = exclude_triple_lines
  if dist_output_file is not None:
    filter.DistOutputFile = dist_output_file
  if err_output_file is not None:
    filter.ErrOutputFile = err_output_file
  if save_relative_err is not None:
    filter.SaveRelativeErr = save_relative_err
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if feature_euler_angles_array_path is not None:
    filter.FeatureEulerAnglesArrayPath = feature_euler_angles_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if surface_mesh_face_normals_array_path is not None:
    filter.SurfaceMeshFaceNormalsArrayPath = surface_mesh_face_normals_array_path
  if surface_mesh_face_areas_array_path is not None:
    filter.SurfaceMeshFaceAreasArrayPath = surface_mesh_face_areas_array_path
  if surface_mesh_feature_face_labels_array_path is not None:
    filter.SurfaceMeshFeatureFaceLabelsArrayPath = surface_mesh_feature_face_labels_array_path
  if node_types_array_path is not None:
    filter.NodeTypesArrayPath = node_types_array_path
  filter.execute()
  return filter.ErrorCode

def find_gbpd_metric_based(data_container_array, phase_of_interest = None, limit_dist = None, num_sampl_pts = None, exclude_triple_lines = None, dist_output_file = None, err_output_file = None, save_relative_err = None, crystal_structures_array_path = None, feature_euler_angles_array_path = None, feature_phases_array_path = None, surface_mesh_face_labels_array_path = None, surface_mesh_face_normals_array_path = None, surface_mesh_face_areas_array_path = None, surface_mesh_feature_face_labels_array_path = None, node_types_array_path = None, observer = None) -> int:
  """Pythonic interface to FindGBPDMetricBased Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    phase_of_interest (int): Sets the "PhaseOfInterest" filter property
    limit_dist (float): Sets the "LimitDist" filter property
    num_sampl_pts (int): Sets the "NumSamplPts" filter property
    exclude_triple_lines (bool): Sets the "ExcludeTripleLines" filter property
    dist_output_file (QString): Sets the "DistOutputFile" filter property
    err_output_file (QString): Sets the "ErrOutputFile" filter property
    save_relative_err (bool): Sets the "SaveRelativeErr" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    feature_euler_angles_array_path (DataArrayPath): Sets the "FeatureEulerAnglesArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    surface_mesh_face_normals_array_path (DataArrayPath): Sets the "SurfaceMeshFaceNormalsArrayPath" filter property
    surface_mesh_face_areas_array_path (DataArrayPath): Sets the "SurfaceMeshFaceAreasArrayPath" filter property
    surface_mesh_feature_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFeatureFaceLabelsArrayPath" filter property
    node_types_array_path (DataArrayPath): Sets the "NodeTypesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindGBPDMetricBased()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if phase_of_interest is not None:
    filter.PhaseOfInterest = phase_of_interest
  if limit_dist is not None:
    filter.LimitDist = limit_dist
  if num_sampl_pts is not None:
    filter.NumSamplPts = num_sampl_pts
  if exclude_triple_lines is not None:
    filter.ExcludeTripleLines = exclude_triple_lines
  if dist_output_file is not None:
    filter.DistOutputFile = dist_output_file
  if err_output_file is not None:
    filter.ErrOutputFile = err_output_file
  if save_relative_err is not None:
    filter.SaveRelativeErr = save_relative_err
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if feature_euler_angles_array_path is not None:
    filter.FeatureEulerAnglesArrayPath = feature_euler_angles_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if surface_mesh_face_normals_array_path is not None:
    filter.SurfaceMeshFaceNormalsArrayPath = surface_mesh_face_normals_array_path
  if surface_mesh_face_areas_array_path is not None:
    filter.SurfaceMeshFaceAreasArrayPath = surface_mesh_face_areas_array_path
  if surface_mesh_feature_face_labels_array_path is not None:
    filter.SurfaceMeshFeatureFaceLabelsArrayPath = surface_mesh_feature_face_labels_array_path
  if node_types_array_path is not None:
    filter.NodeTypesArrayPath = node_types_array_path
  filter.execute()
  return filter.ErrorCode

def find_kernel_avg_misorientations(data_container_array, feature_ids_array_path = None, cell_phases_array_path = None, crystal_structures_array_path = None, quats_array_path = None, kernel_average_misorientations_array_name = None, kernel_size = None, observer = None) -> int:
  """Pythonic interface to FindKernelAvgMisorientations Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    kernel_average_misorientations_array_name (QString): Sets the "KernelAverageMisorientationsArrayName" filter property
    kernel_size (IntVec3Type): Sets the "KernelSize" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindKernelAvgMisorientations()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if kernel_average_misorientations_array_name is not None:
    filter.KernelAverageMisorientationsArrayName = kernel_average_misorientations_array_name
  if kernel_size is not None:
    filter.KernelSize = kernel_size
  filter.execute()
  return filter.ErrorCode

def find_misorientations(data_container_array, neighbor_list_array_path = None, misorientation_list_array_name = None, avg_quats_array_path = None, feature_phases_array_path = None, crystal_structures_array_path = None, avg_misorientations_array_name = None, find_avg_misors = None, observer = None) -> int:
  """Pythonic interface to FindMisorientations Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    neighbor_list_array_path (DataArrayPath): Sets the "NeighborListArrayPath" filter property
    misorientation_list_array_name (QString): Sets the "MisorientationListArrayName" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    avg_misorientations_array_name (QString): Sets the "AvgMisorientationsArrayName" filter property
    find_avg_misors (bool): Sets the "FindAvgMisors" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindMisorientations()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if neighbor_list_array_path is not None:
    filter.NeighborListArrayPath = neighbor_list_array_path
  if misorientation_list_array_name is not None:
    filter.MisorientationListArrayName = misorientation_list_array_name
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if avg_misorientations_array_name is not None:
    filter.AvgMisorientationsArrayName = avg_misorientations_array_name
  if find_avg_misors is not None:
    filter.FindAvgMisors = find_avg_misors
  filter.execute()
  return filter.ErrorCode

def find_schmids(data_container_array, feature_phases_array_path = None, crystal_structures_array_path = None, avg_quats_array_path = None, schmids_array_name = None, slip_systems_array_name = None, poles_array_name = None, phis_array_name = None, lambdas_array_name = None, loading_direction = None, store_angle_components = None, override_system = None, slip_plane = None, slip_direction = None, observer = None) -> int:
  """Pythonic interface to FindSchmids Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    schmids_array_name (QString): Sets the "SchmidsArrayName" filter property
    slip_systems_array_name (QString): Sets the "SlipSystemsArrayName" filter property
    poles_array_name (QString): Sets the "PolesArrayName" filter property
    phis_array_name (QString): Sets the "PhisArrayName" filter property
    lambdas_array_name (QString): Sets the "LambdasArrayName" filter property
    loading_direction (FloatVec3Type): Sets the "LoadingDirection" filter property
    store_angle_components (bool): Sets the "StoreAngleComponents" filter property
    override_system (bool): Sets the "OverrideSystem" filter property
    slip_plane (FloatVec3Type): Sets the "SlipPlane" filter property
    slip_direction (FloatVec3Type): Sets the "SlipDirection" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindSchmids()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if schmids_array_name is not None:
    filter.SchmidsArrayName = schmids_array_name
  if slip_systems_array_name is not None:
    filter.SlipSystemsArrayName = slip_systems_array_name
  if poles_array_name is not None:
    filter.PolesArrayName = poles_array_name
  if phis_array_name is not None:
    filter.PhisArrayName = phis_array_name
  if lambdas_array_name is not None:
    filter.LambdasArrayName = lambdas_array_name
  if loading_direction is not None:
    filter.LoadingDirection = loading_direction
  if store_angle_components is not None:
    filter.StoreAngleComponents = store_angle_components
  if override_system is not None:
    filter.OverrideSystem = override_system
  if slip_plane is not None:
    filter.SlipPlane = slip_plane
  if slip_direction is not None:
    filter.SlipDirection = slip_direction
  filter.execute()
  return filter.ErrorCode

def find_slip_transmission_metrics(data_container_array, neighbor_list_array_path = None, f1_list_array_name = None, f1spt_list_array_name = None, f7_list_array_name = None, m_prime_list_array_name = None, avg_quats_array_path = None, feature_phases_array_path = None, crystal_structures_array_path = None, observer = None) -> int:
  """Pythonic interface to FindSlipTransmissionMetrics Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    neighbor_list_array_path (DataArrayPath): Sets the "NeighborListArrayPath" filter property
    f1_list_array_name (QString): Sets the "F1ListArrayName" filter property
    f1spt_list_array_name (QString): Sets the "F1sptListArrayName" filter property
    f7_list_array_name (QString): Sets the "F7ListArrayName" filter property
    m_prime_list_array_name (QString): Sets the "mPrimeListArrayName" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindSlipTransmissionMetrics()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if neighbor_list_array_path is not None:
    filter.NeighborListArrayPath = neighbor_list_array_path
  if f1_list_array_name is not None:
    filter.F1ListArrayName = f1_list_array_name
  if f1spt_list_array_name is not None:
    filter.F1sptListArrayName = f1spt_list_array_name
  if f7_list_array_name is not None:
    filter.F7ListArrayName = f7_list_array_name
  if m_prime_list_array_name is not None:
    filter.mPrimeListArrayName = m_prime_list_array_name
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  filter.execute()
  return filter.ErrorCode

def find_twin_boundaries(data_container_array, axis_tolerance = None, angle_tolerance = None, find_coherence = None, avg_quats_array_path = None, feature_phases_array_path = None, crystal_structures_array_path = None, surface_mesh_face_labels_array_path = None, surface_mesh_face_normals_array_path = None, surface_mesh_twin_boundary_array_name = None, surface_mesh_twin_boundary_incoherence_array_name = None, observer = None) -> int:
  """Pythonic interface to FindTwinBoundaries Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    axis_tolerance (float): Sets the "AxisTolerance" filter property
    angle_tolerance (float): Sets the "AngleTolerance" filter property
    find_coherence (bool): Sets the "FindCoherence" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    surface_mesh_face_normals_array_path (DataArrayPath): Sets the "SurfaceMeshFaceNormalsArrayPath" filter property
    surface_mesh_twin_boundary_array_name (QString): Sets the "SurfaceMeshTwinBoundaryArrayName" filter property
    surface_mesh_twin_boundary_incoherence_array_name (QString): Sets the "SurfaceMeshTwinBoundaryIncoherenceArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindTwinBoundaries()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if axis_tolerance is not None:
    filter.AxisTolerance = axis_tolerance
  if angle_tolerance is not None:
    filter.AngleTolerance = angle_tolerance
  if find_coherence is not None:
    filter.FindCoherence = find_coherence
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if surface_mesh_face_normals_array_path is not None:
    filter.SurfaceMeshFaceNormalsArrayPath = surface_mesh_face_normals_array_path
  if surface_mesh_twin_boundary_array_name is not None:
    filter.SurfaceMeshTwinBoundaryArrayName = surface_mesh_twin_boundary_array_name
  if surface_mesh_twin_boundary_incoherence_array_name is not None:
    filter.SurfaceMeshTwinBoundaryIncoherenceArrayName = surface_mesh_twin_boundary_incoherence_array_name
  filter.execute()
  return filter.ErrorCode

def find_twin_boundary_schmid_factors(data_container_array, write_file = None, twin_boundary_schmid_factors_file = None, loading_dir = None, avg_quats_array_path = None, feature_phases_array_path = None, crystal_structures_array_path = None, surface_mesh_face_labels_array_path = None, surface_mesh_face_normals_array_path = None, surface_mesh_twin_boundary_array_path = None, surface_mesh_twin_boundary_schmid_factors_array_name = None, observer = None) -> int:
  """Pythonic interface to FindTwinBoundarySchmidFactors Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    write_file (bool): Sets the "WriteFile" filter property
    twin_boundary_schmid_factors_file (QString): Sets the "TwinBoundarySchmidFactorsFile" filter property
    loading_dir (FloatVec3Type): Sets the "LoadingDir" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    surface_mesh_face_normals_array_path (DataArrayPath): Sets the "SurfaceMeshFaceNormalsArrayPath" filter property
    surface_mesh_twin_boundary_array_path (DataArrayPath): Sets the "SurfaceMeshTwinBoundaryArrayPath" filter property
    surface_mesh_twin_boundary_schmid_factors_array_name (QString): Sets the "SurfaceMeshTwinBoundarySchmidFactorsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.FindTwinBoundarySchmidFactors()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if write_file is not None:
    filter.WriteFile = write_file
  if twin_boundary_schmid_factors_file is not None:
    filter.TwinBoundarySchmidFactorsFile = twin_boundary_schmid_factors_file
  if loading_dir is not None:
    filter.LoadingDir = loading_dir
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if surface_mesh_face_normals_array_path is not None:
    filter.SurfaceMeshFaceNormalsArrayPath = surface_mesh_face_normals_array_path
  if surface_mesh_twin_boundary_array_path is not None:
    filter.SurfaceMeshTwinBoundaryArrayPath = surface_mesh_twin_boundary_array_path
  if surface_mesh_twin_boundary_schmid_factors_array_name is not None:
    filter.SurfaceMeshTwinBoundarySchmidFactorsArrayName = surface_mesh_twin_boundary_schmid_factors_array_name
  filter.execute()
  return filter.ErrorCode

def generate_face_ipf_coloring(data_container_array, surface_mesh_face_labels_array_path = None, surface_mesh_face_normals_array_path = None, feature_euler_angles_array_path = None, feature_phases_array_path = None, crystal_structures_array_path = None, surface_mesh_face_ipf_colors_array_name = None, observer = None) -> int:
  """Pythonic interface to GenerateFaceIPFColoring Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    surface_mesh_face_normals_array_path (DataArrayPath): Sets the "SurfaceMeshFaceNormalsArrayPath" filter property
    feature_euler_angles_array_path (DataArrayPath): Sets the "FeatureEulerAnglesArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    surface_mesh_face_ipf_colors_array_name (QString): Sets the "SurfaceMeshFaceIPFColorsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.GenerateFaceIPFColoring()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if surface_mesh_face_normals_array_path is not None:
    filter.SurfaceMeshFaceNormalsArrayPath = surface_mesh_face_normals_array_path
  if feature_euler_angles_array_path is not None:
    filter.FeatureEulerAnglesArrayPath = feature_euler_angles_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if surface_mesh_face_ipf_colors_array_name is not None:
    filter.SurfaceMeshFaceIPFColorsArrayName = surface_mesh_face_ipf_colors_array_name
  filter.execute()
  return filter.ErrorCode

def generate_face_misorientation_coloring(data_container_array, surface_mesh_face_labels_array_path = None, avg_quats_array_path = None, feature_phases_array_path = None, crystal_structures_array_path = None, surface_mesh_face_misorientation_colors_array_name = None, observer = None) -> int:
  """Pythonic interface to GenerateFaceMisorientationColoring Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    avg_quats_array_path (DataArrayPath): Sets the "AvgQuatsArrayPath" filter property
    feature_phases_array_path (DataArrayPath): Sets the "FeaturePhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    surface_mesh_face_misorientation_colors_array_name (QString): Sets the "SurfaceMeshFaceMisorientationColorsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.GenerateFaceMisorientationColoring()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  if avg_quats_array_path is not None:
    filter.AvgQuatsArrayPath = avg_quats_array_path
  if feature_phases_array_path is not None:
    filter.FeaturePhasesArrayPath = feature_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if surface_mesh_face_misorientation_colors_array_name is not None:
    filter.SurfaceMeshFaceMisorientationColorsArrayName = surface_mesh_face_misorientation_colors_array_name
  filter.execute()
  return filter.ErrorCode

def generate_fz_quaternions(data_container_array, cell_phases_array_path = None, quats_array_path = None, crystal_structures_array_path = None, use_good_voxels = None, good_voxels_array_path = None, fz_quats_array_path = None, observer = None) -> int:
  """Pythonic interface to GenerateFZQuaternions Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    use_good_voxels (bool): Sets the "UseGoodVoxels" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    fz_quats_array_path (DataArrayPath): Sets the "FZQuatsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.GenerateFZQuaternions()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if fz_quats_array_path is not None:
    filter.FZQuatsArrayPath = fz_quats_array_path
  filter.execute()
  return filter.ErrorCode

def generate_ipf_colors(data_container_array, reference_dir = None, cell_phases_array_path = None, cell_euler_angles_array_path = None, crystal_structures_array_path = None, use_good_voxels = None, good_voxels_array_path = None, cell_ipf_colors_array_name = None, observer = None) -> int:
  """Pythonic interface to GenerateIPFColors Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    reference_dir (FloatVec3Type): Sets the "ReferenceDir" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    cell_euler_angles_array_path (DataArrayPath): Sets the "CellEulerAnglesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    use_good_voxels (bool): Sets the "UseGoodVoxels" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    cell_ipf_colors_array_name (QString): Sets the "CellIPFColorsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.GenerateIPFColors()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if reference_dir is not None:
    filter.ReferenceDir = reference_dir
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if cell_euler_angles_array_path is not None:
    filter.CellEulerAnglesArrayPath = cell_euler_angles_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if cell_ipf_colors_array_name is not None:
    filter.CellIPFColorsArrayName = cell_ipf_colors_array_name
  filter.execute()
  return filter.ErrorCode

def generate_quaternion_conjugate(data_container_array, quaternion_data_array_path = None, output_data_array_path = None, delete_original_data = None, observer = None) -> int:
  """Pythonic interface to GenerateQuaternionConjugate Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    quaternion_data_array_path (DataArrayPath): Sets the "QuaternionDataArrayPath" filter property
    output_data_array_path (DataArrayPath): Sets the "OutputDataArrayPath" filter property
    delete_original_data (bool): Sets the "DeleteOriginalData" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.GenerateQuaternionConjugate()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if quaternion_data_array_path is not None:
    filter.QuaternionDataArrayPath = quaternion_data_array_path
  if output_data_array_path is not None:
    filter.OutputDataArrayPath = output_data_array_path
  if delete_original_data is not None:
    filter.DeleteOriginalData = delete_original_data
  filter.execute()
  return filter.ErrorCode

def import_ebsd_montage(data_container_array, montage_name = None, data_container_name = None, cell_ensemble_attribute_matrix_name = None, cell_attribute_matrix_name = None, input_file_list_info = None, generate_ipf_color_map = None, cell_ipf_colors_array_name = None, define_scan_overlap = None, scan_overlap_percent = None, observer = None) -> int:
  """Pythonic interface to ImportEbsdMontage Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    montage_name (QString): Sets the "MontageName" filter property
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_ensemble_attribute_matrix_name (QString): Sets the "CellEnsembleAttributeMatrixName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    input_file_list_info (EbsdMontageListInfo): Sets the "InputFileListInfo" filter property
    generate_ipf_color_map (bool): Sets the "GenerateIPFColorMap" filter property
    cell_ipf_colors_array_name (QString): Sets the "CellIPFColorsArrayName" filter property
    define_scan_overlap (int32_t): Sets the "DefineScanOverlap" filter property
    scan_overlap_percent (FloatVec2Type): Sets the "ScanOverlapPercent" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.ImportEbsdMontage()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if montage_name is not None:
    filter.MontageName = montage_name
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_ensemble_attribute_matrix_name is not None:
    filter.CellEnsembleAttributeMatrixName = cell_ensemble_attribute_matrix_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if input_file_list_info is not None:
    filter.InputFileListInfo = input_file_list_info
  if generate_ipf_color_map is not None:
    filter.GenerateIPFColorMap = generate_ipf_color_map
  if cell_ipf_colors_array_name is not None:
    filter.CellIPFColorsArrayName = cell_ipf_colors_array_name
  if define_scan_overlap is not None:
    filter.DefineScanOverlap = define_scan_overlap
  if scan_overlap_percent is not None:
    filter.ScanOverlapPercent = scan_overlap_percent
  filter.execute()
  return filter.ErrorCode

def import_h5_oim_data(data_container_array, input_file = None, selected_scan_names = None, number_of_scans = None, z_spacing = None, origin = None, data_container_name = None, cell_ensemble_attribute_matrix_name = None, cell_attribute_matrix_name = None, read_pattern_data = None, file_was_read = None, observer = None) -> int:
  """Pythonic interface to ImportH5OimData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_file (QString): Sets the "InputFile" filter property
    selected_scan_names (QStringList): Sets the "SelectedScanNames" filter property
    number_of_scans (int): Sets the "NumberOfScans" filter property
    z_spacing (double): Sets the "ZSpacing" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_ensemble_attribute_matrix_name (QString): Sets the "CellEnsembleAttributeMatrixName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    read_pattern_data (bool): Sets the "ReadPatternData" filter property
    file_was_read (bool): Sets the "FileWasRead" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.ImportH5OimData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_file is not None:
    filter.InputFile = input_file
  if selected_scan_names is not None:
    filter.SelectedScanNames = selected_scan_names
  if number_of_scans is not None:
    filter.NumberOfScans = number_of_scans
  if z_spacing is not None:
    filter.ZSpacing = z_spacing
  if origin is not None:
    filter.Origin = origin
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_ensemble_attribute_matrix_name is not None:
    filter.CellEnsembleAttributeMatrixName = cell_ensemble_attribute_matrix_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if read_pattern_data is not None:
    filter.ReadPatternData = read_pattern_data
  if file_was_read is not None:
    filter.FileWasRead = file_was_read
  filter.execute()
  return filter.ErrorCode

def inl_writer(data_container_array, output_file = None, material_name_array_path = None, feature_ids_array_path = None, cell_phases_array_path = None, crystal_structures_array_path = None, num_features_array_path = None, cell_euler_angles_array_path = None, observer = None) -> int:
  """Pythonic interface to INLWriter Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_file (QString): Sets the "OutputFile" filter property
    material_name_array_path (DataArrayPath): Sets the "MaterialNameArrayPath" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    num_features_array_path (DataArrayPath): Sets the "NumFeaturesArrayPath" filter property
    cell_euler_angles_array_path (DataArrayPath): Sets the "CellEulerAnglesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.INLWriter()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if material_name_array_path is not None:
    filter.MaterialNameArrayPath = material_name_array_path
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if num_features_array_path is not None:
    filter.NumFeaturesArrayPath = num_features_array_path
  if cell_euler_angles_array_path is not None:
    filter.CellEulerAnglesArrayPath = cell_euler_angles_array_path
  filter.execute()
  return filter.ErrorCode

def neighbor_orientation_correlation(data_container_array, misorientation_tolerance = None, min_confidence = None, level = None, confidence_index_array_path = None, cell_phases_array_path = None, crystal_structures_array_path = None, quats_array_path = None, observer = None) -> int:
  """Pythonic interface to NeighborOrientationCorrelation Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    misorientation_tolerance (float): Sets the "MisorientationTolerance" filter property
    min_confidence (float): Sets the "MinConfidence" filter property
    level (int): Sets the "Level" filter property
    confidence_index_array_path (DataArrayPath): Sets the "ConfidenceIndexArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.NeighborOrientationCorrelation()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if misorientation_tolerance is not None:
    filter.MisorientationTolerance = misorientation_tolerance
  if min_confidence is not None:
    filter.MinConfidence = min_confidence
  if level is not None:
    filter.Level = level
  if confidence_index_array_path is not None:
    filter.ConfidenceIndexArrayPath = confidence_index_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  filter.execute()
  return filter.ErrorCode

def read_ang_data(data_container_array, data_container_name = None, cell_ensemble_attribute_matrix_name = None, cell_attribute_matrix_name = None, input_file = None, observer = None) -> int:
  """Pythonic interface to ReadAngData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_ensemble_attribute_matrix_name (QString): Sets the "CellEnsembleAttributeMatrixName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    input_file (QString): Sets the "InputFile" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.ReadAngData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_ensemble_attribute_matrix_name is not None:
    filter.CellEnsembleAttributeMatrixName = cell_ensemble_attribute_matrix_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if input_file is not None:
    filter.InputFile = input_file
  filter.execute()
  return filter.ErrorCode

def read_ctf_data(data_container_array, data_container_name = None, cell_ensemble_attribute_matrix_name = None, cell_attribute_matrix_name = None, input_file = None, degrees_to_radians = None, edax_hexagonal_alignment = None, observer = None) -> int:
  """Pythonic interface to ReadCtfData Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_ensemble_attribute_matrix_name (QString): Sets the "CellEnsembleAttributeMatrixName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    input_file (QString): Sets the "InputFile" filter property
    degrees_to_radians (bool): Sets the "DegreesToRadians" filter property
    edax_hexagonal_alignment (bool): Sets the "EdaxHexagonalAlignment" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.ReadCtfData()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_ensemble_attribute_matrix_name is not None:
    filter.CellEnsembleAttributeMatrixName = cell_ensemble_attribute_matrix_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if input_file is not None:
    filter.InputFile = input_file
  if degrees_to_radians is not None:
    filter.DegreesToRadians = degrees_to_radians
  if edax_hexagonal_alignment is not None:
    filter.EdaxHexagonalAlignment = edax_hexagonal_alignment
  filter.execute()
  return filter.ErrorCode

def read_h5_ebsd(data_container_array, data_container_name = None, cell_ensemble_attribute_matrix_name = None, cell_attribute_matrix_name = None, input_file = None, z_start_index = None, z_end_index = None, use_transformations = None, angle_representation = None, selected_array_names = None, observer = None) -> int:
  """Pythonic interface to ReadH5Ebsd Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_ensemble_attribute_matrix_name (QString): Sets the "CellEnsembleAttributeMatrixName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    input_file (QString): Sets the "InputFile" filter property
    z_start_index (int): Sets the "ZStartIndex" filter property
    z_end_index (int): Sets the "ZEndIndex" filter property
    use_transformations (bool): Sets the "UseTransformations" filter property
    angle_representation (int): Sets the "AngleRepresentation" filter property
    selected_array_names (QSet<QString>): Sets the "SelectedArrayNames" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.ReadH5Ebsd()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_ensemble_attribute_matrix_name is not None:
    filter.CellEnsembleAttributeMatrixName = cell_ensemble_attribute_matrix_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if input_file is not None:
    filter.InputFile = input_file
  if z_start_index is not None:
    filter.ZStartIndex = z_start_index
  if z_end_index is not None:
    filter.ZEndIndex = z_end_index
  if use_transformations is not None:
    filter.UseTransformations = use_transformations
  if angle_representation is not None:
    filter.AngleRepresentation = angle_representation
  if selected_array_names is not None:
    filter.SelectedArrayNames = selected_array_names
  filter.execute()
  return filter.ErrorCode

def replace_element_attributes_with_neighbor_values(data_container_array, min_confidence = None, loop = None, confidence_index_array_path = None, selected_comparison = None, observer = None) -> int:
  """Pythonic interface to ReplaceElementAttributesWithNeighborValues Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    min_confidence (float): Sets the "MinConfidence" filter property
    loop (bool): Sets the "Loop" filter property
    confidence_index_array_path (DataArrayPath): Sets the "ConfidenceIndexArrayPath" filter property
    selected_comparison (int): Sets the "SelectedComparison" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.ReplaceElementAttributesWithNeighborValues()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if min_confidence is not None:
    filter.MinConfidence = min_confidence
  if loop is not None:
    filter.Loop = loop
  if confidence_index_array_path is not None:
    filter.ConfidenceIndexArrayPath = confidence_index_array_path
  if selected_comparison is not None:
    filter.SelectedComparison = selected_comparison
  filter.execute()
  return filter.ErrorCode

def rotate_euler_ref_frame(data_container_array, rotation_axis = None, rotation_angle = None, cell_euler_angles_array_path = None, observer = None) -> int:
  """Pythonic interface to RotateEulerRefFrame Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    rotation_axis (FloatVec3Type): Sets the "RotationAxis" filter property
    rotation_angle (float): Sets the "RotationAngle" filter property
    cell_euler_angles_array_path (DataArrayPath): Sets the "CellEulerAnglesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.RotateEulerRefFrame()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if rotation_axis is not None:
    filter.RotationAxis = rotation_axis
  if rotation_angle is not None:
    filter.RotationAngle = rotation_angle
  if cell_euler_angles_array_path is not None:
    filter.CellEulerAnglesArrayPath = cell_euler_angles_array_path
  filter.execute()
  return filter.ErrorCode

def stereographic3_d(data_container_array, quats_array_path = None, coordinates_array_name = None, observer = None) -> int:
  """Pythonic interface to Stereographic3D Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    quats_array_path (DataArrayPath): Sets the "QuatsArrayPath" filter property
    coordinates_array_name (QString): Sets the "CoordinatesArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.Stereographic3D()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if quats_array_path is not None:
    filter.QuatsArrayPath = quats_array_path
  if coordinates_array_name is not None:
    filter.CoordinatesArrayName = coordinates_array_name
  filter.execute()
  return filter.ErrorCode

def write_pole_figure(data_container_array, image_prefix = None, output_path = None, image_format = None, image_size = None, lambert_size = None, num_colors = None, image_layout = None, cell_euler_angles_array_path = None, cell_phases_array_path = None, crystal_structures_array_path = None, material_name_array_path = None, good_voxels_array_path = None, use_good_voxels = None, generation_algorithm = None, observer = None) -> int:
  """Pythonic interface to WritePoleFigure Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    image_prefix (QString): Sets the "ImagePrefix" filter property
    output_path (QString): Sets the "OutputPath" filter property
    image_format (int): Sets the "ImageFormat" filter property
    image_size (int): Sets the "ImageSize" filter property
    lambert_size (int): Sets the "LambertSize" filter property
    num_colors (int): Sets the "NumColors" filter property
    image_layout (int): Sets the "ImageLayout" filter property
    cell_euler_angles_array_path (DataArrayPath): Sets the "CellEulerAnglesArrayPath" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    crystal_structures_array_path (DataArrayPath): Sets the "CrystalStructuresArrayPath" filter property
    material_name_array_path (DataArrayPath): Sets the "MaterialNameArrayPath" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    use_good_voxels (bool): Sets the "UseGoodVoxels" filter property
    generation_algorithm (int): Sets the "GenerationAlgorithm" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.WritePoleFigure()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if image_prefix is not None:
    filter.ImagePrefix = image_prefix
  if output_path is not None:
    filter.OutputPath = output_path
  if image_format is not None:
    filter.ImageFormat = image_format
  if image_size is not None:
    filter.ImageSize = image_size
  if lambert_size is not None:
    filter.LambertSize = lambert_size
  if num_colors is not None:
    filter.NumColors = num_colors
  if image_layout is not None:
    filter.ImageLayout = image_layout
  if cell_euler_angles_array_path is not None:
    filter.CellEulerAnglesArrayPath = cell_euler_angles_array_path
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if crystal_structures_array_path is not None:
    filter.CrystalStructuresArrayPath = crystal_structures_array_path
  if material_name_array_path is not None:
    filter.MaterialNameArrayPath = material_name_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  if generation_algorithm is not None:
    filter.GenerationAlgorithm = generation_algorithm
  filter.execute()
  return filter.ErrorCode

def write_stats_gen_odf_angle_file(data_container_array, output_file = None, weight = None, sigma = None, delimiter = None, cell_phases_array_path = None, cell_euler_angles_array_path = None, good_voxels_array_path = None, convert_to_degrees = None, use_good_voxels = None, observer = None) -> int:
  """Pythonic interface to WriteStatsGenOdfAngleFile Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    output_file (QString): Sets the "OutputFile" filter property
    weight (float): Sets the "Weight" filter property
    sigma (int): Sets the "Sigma" filter property
    delimiter (int): Sets the "Delimiter" filter property
    cell_phases_array_path (DataArrayPath): Sets the "CellPhasesArrayPath" filter property
    cell_euler_angles_array_path (DataArrayPath): Sets the "CellEulerAnglesArrayPath" filter property
    good_voxels_array_path (DataArrayPath): Sets the "GoodVoxelsArrayPath" filter property
    convert_to_degrees (bool): Sets the "ConvertToDegrees" filter property
    use_good_voxels (bool): Sets the "UseGoodVoxels" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = orientationanalysis.WriteStatsGenOdfAngleFile()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if output_file is not None:
    filter.OutputFile = output_file
  if weight is not None:
    filter.Weight = weight
  if sigma is not None:
    filter.Sigma = sigma
  if delimiter is not None:
    filter.Delimiter = delimiter
  if cell_phases_array_path is not None:
    filter.CellPhasesArrayPath = cell_phases_array_path
  if cell_euler_angles_array_path is not None:
    filter.CellEulerAnglesArrayPath = cell_euler_angles_array_path
  if good_voxels_array_path is not None:
    filter.GoodVoxelsArrayPath = good_voxels_array_path
  if convert_to_degrees is not None:
    filter.ConvertToDegrees = convert_to_degrees
  if use_good_voxels is not None:
    filter.UseGoodVoxels = use_good_voxels
  filter.execute()
  return filter.ErrorCode

